#
# spec file for package ghc-optics
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name optics
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.4
Release:        bp155.2.14
Summary:        Optics as an abstract interface
License:        BSD-3-Clause
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-optics-core-devel
BuildRequires:  ghc-optics-extra-devel
BuildRequires:  ghc-optics-th-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-transformers-devel
ExcludeArch:    %{ix86}
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-indexed-profunctors-devel
BuildRequires:  ghc-inspection-testing-devel
BuildRequires:  ghc-random-devel
BuildRequires:  ghc-tasty-devel
BuildRequires:  ghc-tasty-hunit-devel
BuildRequires:  ghc-tasty-quickcheck-devel
BuildRequires:  ghc-template-haskell-devel
%endif

%description
This package makes it possible to define and use Lenses, Traversals, Prisms and
other optics, using an abstract interface. See the main module "Optics" for the
documentation.

This is the "batteries-included" variant with many dependencies; see the
'<https://hackage.haskell.org/package/optics-core optics-core>' package and
other 'optics-*' dependencies if you need a more limited dependency footprint.

Note: Hackage does not yet display documentation for reexported-modules, but
you can start from the "Optics" module documentation or see the module list in
'<https://hackage.haskell.org/package/optics-core optics-core>'.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%autosetup -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc CHANGELOG.md

%changelog
* Tue Feb 23 2021 psimons@suse.com
- Update optics to version 0.4.
  [#] optics-0.4 (2021-02-22)
  * See [migration-guide-0.4.md](https://github.com/well-typed/optics/blob/master/migration-guide-0.4.md) for more details
  * Add support for GHC-9.0
  * Drop support for GHC-8.0
  * The `FunctorWithIndex`, `FoldableWithIndex` and `TraversableWithIndex` type
    classes have been migrated to a new package,
    [`indexed-traversable`](https://hackage.haskell.org/package/indexed-traversable)
    ([#370](https://github.com/well-typed/optics/pull/370))
  * Add `adjoin`, `iadjoin` and `both` to `Optics.[Ix]Traversal`
    ([#332](https://github.com/well-typed/optics/pull/332),
    [#372](https://github.com/well-typed/optics/pull/372))
  * Add `ifst` and `isnd` to `Optics.IxLens`
    ([#389](https://github.com/well-typed/optics/pull/389))
  * Generalize types of `generic`
    ([#376](https://github.com/well-typed/optics/pull/376))
  * Make `chosen` an indexed lens to see which value is traversed
    ([#335](https://github.com/well-typed/optics/pull/335))
  * Remove `GeneralLabelOptic` extensibility mechanism
    ([#361](https://github.com/well-typed/optics/pull/361))
  * Add `gfield`, `gafield`, `gconstructor`, `gposition` and `gplate` for
    generics-based data access
    ([#358](https://github.com/well-typed/optics/pull/358),
    [#361](https://github.com/well-typed/optics/pull/361))
  * Add support for generics-based field lenses and constructor prisms (`gfield`
    and `gconstructor`) to `LabelOptic` so they can be used via `OverloadedLabels`
    ([#361](https://github.com/well-typed/optics/pull/361))
  * Remove unnecessary INLINE pragmas to reduce compile times
    ([#394](https://github.com/well-typed/optics/pull/394))
  * Simplify the type of `(%%)` using new `JoinKinds` and `AppendIndices` classes
    in place of the `Join` and `Append` type families
    ([#397](https://github.com/well-typed/optics/pull/397),
    [#399](https://github.com/well-typed/optics/pull/399))
  * Print missing language extensions during TH generation of labels if there are
    any ([#352](https://github.com/well-typed/optics/pull/352))
  * Add support for getters of rank1 polymorphic fields to optics generated with
    the `makeFieldLabels` family of functions
    ([#365](https://github.com/well-typed/optics/pull/365))
  * Extend support of type-changing optics generated with the `makeFieldLabels`
    family to type parameters that are phantom and applied to non-injective type
    families
    ([#365](https://github.com/well-typed/optics/pull/365))
  * Fix TH generation of optics for poly-kinded data families
    ([#378](https://github.com/well-typed/optics/pull/378))
  * Fix `declareFieldLabels` when a field type refers to a type defined in the
    same quote
    ([#380](https://github.com/well-typed/optics/pull/380))
* Thu Dec 17 2020 Ondřej Súkup <mimi.vx@gmail.com>
- disable %%{ix86} build
* Tue Sep  1 2020 psimons@suse.com
- Add optics at version 0.3.
